<?xml version="1.0" ?>
<!--                                                                        -->
<!-- Licensed Materials - Property of IBM                                   -->
<!-- Copyright IBM Corp. 2003, 2004.  All Rights Reserved.                  -->
<!--                                                                        -->
<!-- US Government Users Restricted Rights - Use, duplication or disclosure -->
<!-- restricted by GSA ADP Schedule Contract with IBM Corp.                 -->
<!--                                                                        -->
<xsl:stylesheet 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	version="1.0"
    xmlns:xmi="http://www.omg.org/XMI" 
    xmlns:uml="http://www.eclipse.org/uml2/1.0.0/UML"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:publish="http://www.ibm.com/Rational/XTools/Publish"
    xmlns:xalan="http://xml.apache.org/xalan" 
    exclude-result-prefixes="xmi uml xsi publish xalan">


    <xsl:output encoding="UTF-8" method="html"/>
    
    
    <!-- ................... main template .................... -->
    <xsl:template match="/">
        <xsl:apply-templates select="publish:project"/>
    </xsl:template>
    
    <!-- ...................... publish:project .......................-->
    <xsl:template match="publish:project" name="createProjectIndex">
        <html>
            <head>
                <!-- the META element allows the support of native folders in external link URLs
                     otherwise IE is not capable of navigating to such links
                  -->
                <META http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
				<meta http-equiv="X-UA-Compatible" content="IE=7,8,9,10" />
                <title>
                    <xsl:value-of select="@name"/>
                </title>
                <link href="content/WebPublish.css" rel="stylesheet" type="text/css"/>
            </head>
            <body>
                <img src="{@publishBannerPath}" alt=""/>
                <p align="right">
                    <xsl:value-of select="@publishDateTime"/>                    
                </p>  
                <xsl:if test = "@publishCompany">
	                <p align="right">
	                    <i><xsl:value-of select="@publishCompany"/></i>                    
	                </p>  
	           </xsl:if>
                <xsl:if test = "@publishAuthor">
	                <p align="right">
	                    <i><xsl:value-of select="@publishAuthor"/></i>               
	                </p>  
	           </xsl:if>
                <p class="LargeTitle">
                    <xsl:value-of select="@name"/>
                </p>
                <table border="0" cellpadding="10">
                    <xsl:apply-templates select="publish:link"/>
                </table>
            </body>
        </html>
    </xsl:template>
    <!--  
    For this template, set the output method to "xml". If the method is set to "html", the xsl
    engine outputs the value of href attributes as a series of bytes of the form %E3%82%AD 
    for international languages. This is what W3C actually recommends. However, MS IE 6.0 (and 
    presumably earlier versions) is not able to handle a link with the UTF-8 characters which
    are presented as a series of byte values. If the output method is changed to "xml", the xsl
    transforms engine does not convert href attributes to a sequence of bytes. This keeps 
    IE happy.
    :original author
    -->
    
    <!-- However changing the output method here generates an error at transformation execution time. 
    The error complains about "multiple change of the output method with the template. Commented out the
    change to "xml" output method.
         
    :B.Dubauski 11/22/05 
    -->
        
    <!--............. publish:link .....................-->
    <!--xsl:output encoding="UTF-8" method="xml"/-->
    <xsl:template match="publish:link" name="createProjectLinks">
        <tr>
            <td nowrap="">
                <p>
                    <a>
                        <xsl:attribute name="href">
                            <xsl:value-of select="@publish:filename"/>
                        </xsl:attribute>
                        <xsl:value-of select="@name"/>
                    </a>
                </p>
            </td>
            <td>
				<xsl:call-template name="replaceXML2HTMLLineBreaks">
					<xsl:with-param name="theText">
						<xsl:value-of select="@publish:description"/>
					</xsl:with-param>
				</xsl:call-template>
            </td>
        </tr>
    </xsl:template>
    
    <!-- useful utility for showing text with line breaks in it 
        Note that XML style end-of-line characters will not be displayed properly
        in the output HTML file unless you call this template
        
        NOTE. This is a copy of template from HTMLUtility.xsl in the cix.publish.uml2
        Always copy the original instead modifying the values here.
    -->
    <xsl:template name="replaceXML2HTMLLineBreaks">
        <xsl:param name="theText">ERROR-MISSING-PARAMETER</xsl:param>
        <!-- pass #1: replace DOS style end of line characters -->
        <xsl:variable name="replaceDosEols">
            <xsl:call-template name="replaceSubString">
                <xsl:with-param name="theString">
                    <xsl:value-of select="$theText"/>
                </xsl:with-param>
                <xsl:with-param name="matchSubString">
                    <xsl:text>&#xd;&#xa;</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="replaceWith">
                    <xsl:text>&lt;/br&gt;</xsl:text>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:variable>
        <!-- pass #2: replace UNIX style end of line characters -->
        <xsl:variable name="replaceUnixEols">
            <xsl:call-template name="replaceSubString">
                <xsl:with-param name="theString">
                    <xsl:value-of select="$replaceDosEols"/>
                </xsl:with-param>
                <xsl:with-param name="matchSubString">
                    <xsl:text>&#xa;</xsl:text>
                </xsl:with-param>
                <xsl:with-param name="replaceWith">
                    <xsl:text>&lt;/br&gt;</xsl:text>
                </xsl:with-param>
            </xsl:call-template>
        </xsl:variable>
        <xsl:value-of select="$replaceUnixEols" disable-output-escaping="yes"/>
    </xsl:template>
    
    
    <!-- The template replaceSubString will replace all occurances of a sub string with a replacement string.
       If there are no occurrences of matchSubString in theString then the result of the template is theString.
       
       Parameters:
         theString - the string which contains the sub strings to be replaced
         matchSubString - the sub string to be replaced
         replaceWith - the new string to replace matchSubString with
         
        NOTE. This is a copy of template from StringUtility.xsl in the cix.publish.uml2
        Always copy the original instead modifying the values here.
         
  -->
    <xsl:template name="replaceSubString">
        <xsl:param name="theString"/>
        <xsl:param name="matchSubString"/>
        <xsl:param name="replaceWith"/>
        <xsl:choose>
            <xsl:when test="contains($theString,$matchSubString)">
                <xsl:value-of select="substring-before($theString,$matchSubString)"/>
                <xsl:value-of select="$replaceWith"/>
                <xsl:call-template name="replaceSubString">
                    <xsl:with-param name="theString" select="substring-after($theString,$matchSubString)"/>
                    <xsl:with-param name="matchSubString" select="$matchSubString"/>
                    <xsl:with-param name="replaceWith" select="$replaceWith"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$theString"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
</xsl:stylesheet>
